@@ -19,20 +19,23 @@ from manilaclient.common._i18n import _
 
 class SetShareService(command.Command):
     """Enable/disable share service (Admin only)."""
+
     _description = _("Enable/Disable share service (Admin only).")
 
     def get_parser(self, prog_name):
-        parser = super(SetShareService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'host',
             metavar='<host>',
-            help=_("Host name as 'example_host@example_backend'.")
+            help=_("Host name as 'example_host@example_backend'."),
         )
         parser.add_argument(
             'binary',
             metavar='<binary>',
-            help=_("Service binary, could be 'manila-share', "
-                   "'manila-scheduler' or 'manila-data'")
+            help=_(
+                "Service binary, could be 'manila-share', "
+                "'manila-scheduler' or 'manila-data'"
+            ),
         )
         enable_group = parser.add_mutually_exclusive_group()
         enable_group.add_argument(
@@ -48,15 +51,19 @@ class SetShareService(command.Command):
         parser.add_argument(
             "--disable-reason",
             metavar="<reason>",
-            help=_("Reason for disabling the service "
-                   "(should be used with --disable option)")
+            help=_(
+                "Reason for disabling the service "
+                "(should be used with --disable option)"
+            ),
         )
         return parser
 
     def take_action(self, parsed_args):
         if parsed_args.disable_reason and not parsed_args.disable:
-            msg = _("Cannot specify option --disable-reason without "
-                    "--disable specified.")
+            msg = _(
+                "Cannot specify option --disable-reason without "
+                "--disable specified."
+            )
             raise exceptions.CommandError(msg)
 
         share_client = self.app.client_manager.share
@@ -64,66 +71,79 @@ class SetShareService(command.Command):
         if parsed_args.enable:
             try:
                 share_client.services.enable(
-                    parsed_args.host, parsed_args.binary)
+                    parsed_args.host, parsed_args.binary
+                )
             except Exception as e:
-                raise exceptions.CommandError(_(
-                    "Failed to enable service: %s" % e))
+                msg = _("Failed to enable service: %(e)s")
+                raise exceptions.CommandError(msg % {'e': e})
 
         if parsed_args.disable:
             if parsed_args.disable_reason:
                 if share_client.api_version < api_versions.APIVersion("2.83"):
                     raise exceptions.CommandError(
                         "Service disable reason can be specified only with "
-                        "manila API version >= 2.83")
+                        "manila API version >= 2.83"
+                    )
             try:
                 if parsed_args.disable_reason:
                     share_client.services.disable(
-                        parsed_args.host, parsed_args.binary,
-                        disable_reason=parsed_args.disable_reason)
+                        parsed_args.host,
+                        parsed_args.binary,
+                        disable_reason=parsed_args.disable_reason,
+                    )
                 else:
                     share_client.services.disable(
-                        parsed_args.host, parsed_args.binary)
+                        parsed_args.host, parsed_args.binary
+                    )
             except Exception as e:
-                raise exceptions.CommandError(_(
-                    "Failed to disable service: %s" % e))
+                msg = _("Failed to disable service: %(e)s")
+                raise exceptions.CommandError(msg % {'e': e})
 
 
 class ListShareService(command.Lister):
     """List share services (Admin only)."""
+
     _description = _("List share services (Admin only).")
 
     def get_parser(self, prog_name):
-        parser = super(ListShareService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "--host",
             metavar="<host>",
             default=None,
-            help=_("Filter services by name of the host.")
+            help=_("Filter services by name of the host."),
         )
         parser.add_argument(
             "--binary",
             metavar="<binary>",
             default=None,
-            help=_("Filter services by the name of the service.")
+            help=_("Filter services by the name of the service."),
         )
         parser.add_argument(
             "--status",
             metavar="<status>",
             default=None,
-            help=_("Filter results by status.")
+            help=_("Filter results by status."),
         )
         parser.add_argument(
             "--state",
             metavar="<state>",
             default=None,
             choices=['up', 'down'],
-            help=_("Filter results by state.")
+            help=_("Filter results by state."),
         )
         parser.add_argument(
             "--zone",
             metavar="<zone>",
             default=None,
-            help=_("Filter services by their availability zone.")
+            help=_("Filter services by their availability zone."),
+        )
+        parser.add_argument(
+            "--ensuring",
+            metavar="<ensuring>",
+            choices=['True', 'False'],
+            default=None,
+            help=_("Filter services running ensure shares or not."),
         )
         return parser
 
@@ -137,6 +157,14 @@ class ListShareService(command.Lister):
             'state': parsed_args.state,
             'zone': parsed_args.zone,
         }
+        if parsed_args.ensuring:
+            if share_client.api_version < api_versions.APIVersion("2.93"):
+                raise exceptions.CommandError(
+                    "Filtering services whether they are running ensure "
+                    "shares or not is only supported by manila API version "
+                    ">= 2.93"
+                )
+            search_opts['ensuring'] = parsed_args.ensuring
 
         services = share_client.services.list(search_opts=search_opts)
 
@@ -147,30 +175,34 @@ class ListShareService(command.Lister):
             'Zone',
             'Status',
             'State',
-            'Updated At'
+            'Updated At',
         ]
         if share_client.api_version >= api_versions.APIVersion("2.83"):
             columns.append('Disabled Reason')
-        if share_client.api_version >= api_versions.APIVersion("2.86"):
+        if share_client.api_version >= api_versions.APIVersion("2.93"):
             columns.append('Ensuring')
 
-        data = (osc_utils.get_dict_properties(
-            service._info, columns) for service in services)
+        data = (
+            osc_utils.get_dict_properties(service._info, columns)
+            for service in services
+        )
 
         return (columns, data)
 
 
 class EnsureShareService(command.Command):
     """Run ensure shares in a back end (Admin only)."""
+
     _description = _("Run ensure shares in a back end (Admin only).")
 
     def get_parser(self, prog_name):
-        parser = super(EnsureShareService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'host',
             metavar='<host>',
-            help=_("Host to run ensure shares. "
-                   "'example_host@example_backend'.")
+            help=_(
+                "Host to run ensure shares. 'example_host@example_backend'."
+            ),
         )
         return parser
 
@@ -180,11 +212,11 @@ class EnsureShareService(command.Command):
         if share_client.api_version < api_versions.APIVersion("2.86"):
             raise exceptions.CommandError(
                 "Ensure shares API is only available in "
-                "manila API version >= 2.86")
+                "manila API version >= 2.86"
+            )
 
         try:
             share_client.services.ensure_shares(parsed_args.host)
         except Exception as e:
-            raise exceptions.CommandError(
-                _("Failed to run ensure shares: %s" % e)
-            )
+            msg = _("Failed to ensure shares: %(e)s")
+            raise exceptions.CommandError(msg % {'e': e})
