@@ -26,9 +26,8 @@ from manilaclient.tests.unit.osc.v2 import fakes as manila_fakes
 
 
 class TestShareServer(manila_fakes.TestShare):
-
     def setUp(self):
-        super(TestShareServer, self).setUp()
+        super().setUp()
 
         self.servers_mock = self.app.client_manager.share.share_servers
         self.servers_mock.reset_mock()
@@ -37,16 +36,15 @@ class TestShareServer(manila_fakes.TestShare):
         self.share_networks_mock.reset_mock()
 
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            api_versions.MAX_VERSION)
+            api_versions.MAX_VERSION
+        )
 
 
 class TestDeleteShareServer(TestShareServer):
-
     def setUp(self):
-        super(TestDeleteShareServer, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server())
+        self.share_server = manila_fakes.FakeShareServer.create_one_server()
         self.servers_mock.get.return_value = self.share_server
 
         self.cmd = osc_share_servers.DeleteShareServer(self.app, None)
@@ -55,33 +53,30 @@ class TestDeleteShareServer(TestShareServer):
         arglist = []
         verifylist = []
 
-        self.assertRaises(osc_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, verifylist)
+        self.assertRaises(
+            osc_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_share_server_delete(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_servers', [self.share_server.id])
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_servers', [self.share_server.id])]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
-        self.servers_mock.delete.assert_called_once_with(
-            self.share_server)
+        self.servers_mock.delete.assert_called_once_with(self.share_server)
         self.assertIsNone(result)
 
     def test_share_server_delete_wait(self):
-        arglist = [
-            self.share_server.id,
-            '--wait'
-        ]
+        arglist = [self.share_server.id, '--wait']
         verifylist = [
             ('share_servers', [self.share_server.id]),
-            ('wait', True)
+            ('wait', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -89,37 +84,29 @@ class TestDeleteShareServer(TestShareServer):
         with mock.patch('osc_lib.utils.wait_for_delete', return_value=True):
             result = self.cmd.take_action(parsed_args)
 
-            self.servers_mock.delete.assert_called_once_with(
-                self.share_server)
+            self.servers_mock.delete.assert_called_once_with(self.share_server)
             self.assertIsNone(result)
 
     def test_share_server_delete_wait_exception(self):
-        arglist = [
-            self.share_server.id,
-            '--wait'
-        ]
+        arglist = [self.share_server.id, '--wait']
         verifylist = [
             ('share_servers', [self.share_server.id]),
-            ('wait', True)
+            ('wait', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         with mock.patch('osc_lib.utils.wait_for_delete', return_value=False):
             self.assertRaises(
-                exceptions.CommandError,
-                self.cmd.take_action,
-                parsed_args
+                exceptions.CommandError, self.cmd.take_action, parsed_args
             )
 
 
 class TestShowShareServer(TestShareServer):
-
     def setUp(self):
-        super(TestShowShareServer, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server())
+        self.share_server = manila_fakes.FakeShareServer.create_one_server()
         self.servers_mock.get.return_value = self.share_server
 
         self.cmd = osc_share_servers.ShowShareServer(self.app, None)
@@ -133,30 +120,27 @@ class TestShowShareServer(TestShareServer):
 
         self.assertRaises(
             osc_utils.ParserException,
-            self.check_parser, self.cmd, arglist, verifylist)
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_share_server_show(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_server', self.share_server.id)
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_server', self.share_server.id)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.servers_mock.get.assert_called_with(
-            self.share_server.id
-        )
+        self.servers_mock.get.assert_called_with(self.share_server.id)
 
         self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
 
 class TestListShareServer(TestShareServer):
-
     columns = [
         'ID',
         'Host',
@@ -166,15 +150,17 @@ class TestListShareServer(TestShareServer):
     ]
 
     def setUp(self):
-        super(TestListShareServer, self).setUp()
+        super().setUp()
 
-        self.servers_list = (
-            manila_fakes.FakeShareServer.create_share_servers(
-                count=2))
+        self.servers_list = manila_fakes.FakeShareServer.create_share_servers(
+            count=2
+        )
         self.servers_mock.list.return_value = self.servers_list
 
-        self.values = (oscutils.get_dict_properties(
-            i._info, self.columns) for i in self.servers_list)
+        self.values = (
+            oscutils.get_dict_properties(i._info, self.columns)
+            for i in self.servers_list
+        )
 
         self.cmd = osc_share_servers.ListShareServer(self.app, None)
 
@@ -186,18 +172,21 @@ class TestListShareServer(TestShareServer):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.servers_mock.list.assert_called_with(search_opts={
-            'status': None,
-            'host': None,
-            'project_id': None,
-        })
+        self.servers_mock.list.assert_called_with(
+            search_opts={
+                'status': None,
+                'host': None,
+                'project_id': None,
+            }
+        )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(list(self.values), list(data))
 
     def test_share_server_list_by_status(self):
         arglist = [
-            '--status', self.servers_list[0].status,
+            '--status',
+            self.servers_list[0].status,
         ]
         verifylist = [
             ('status', self.servers_list[0].status),
@@ -220,11 +209,12 @@ class TestListShareServer(TestShareServer):
         self.assertEqual(list(self.values), list(data))
 
     def test_share_server_list_by_source_share_server(self):
-        expected_source_share_server_id = (
-            self.servers_list[0].source_share_server_id
-        )
+        expected_source_share_server_id = self.servers_list[
+            0
+        ].source_share_server_id
         arglist = [
-            '--source-share-server-id', expected_source_share_server_id,
+            '--source-share-server-id',
+            expected_source_share_server_id,
         ]
         verifylist = [
             ('source_share_server_id', expected_source_share_server_id),
@@ -249,8 +239,13 @@ class TestListShareServer(TestShareServer):
 
     def test_share_server_list_by_identifier(self):
         expected_identifier = self.servers_list[0].identifier
-        arglist = ['--identifier', expected_identifier,]
-        verifylist = [('identifier', expected_identifier),]
+        arglist = [
+            '--identifier',
+            expected_identifier,
+        ]
+        verifylist = [
+            ('identifier', expected_identifier),
+        ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
@@ -271,29 +266,31 @@ class TestListShareServer(TestShareServer):
 
 
 class TestAdoptShareServer(TestShareServer):
-
     def setUp(self):
-        super(TestAdoptShareServer, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                attrs={'status': 'available'}
-            ))
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            attrs={'status': 'available'}
+        )
         self.servers_mock.get.return_value = self.share_server
         self.servers_mock.manage.return_value = self.share_server
         self.share_network_subnets_mock = (
-            self.app.client_manager.share.share_network_subnets)
+            self.app.client_manager.share.share_network_subnets
+        )
 
         self.share_network = (
             manila_fakes.FakeShareNetwork.create_one_share_network(
                 attrs={'status': 'available'}
-            ))
+            )
+        )
         self.share_network_subnet = (
-            manila_fakes.FakeShareNetworkSubnet.create_one_share_subnet())
+            manila_fakes.FakeShareNetworkSubnet.create_one_share_subnet()
+        )
 
         self.share_networks_mock.get.return_value = self.share_network
         self.share_network_subnets_mock.get.return_value = (
-            self.share_network_subnet)
+            self.share_network_subnet
+        )
 
         self.cmd = osc_share_servers.AdoptShareServer(self.app, None)
 
@@ -304,15 +301,21 @@ class TestAdoptShareServer(TestShareServer):
         arglist = []
         verifylist = []
 
-        self.assertRaises(osc_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, verifylist)
+        self.assertRaises(
+            osc_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_share_server_adopt(self):
         arglist = [
             'somehost@backend',
             self.share_network['id'],
             'share_server_identifier',
-            '--share-network-subnet', self.share_network_subnet['id'],
+            '--share-network-subnet',
+            self.share_network_subnet['id'],
         ]
         verifylist = [
             ('host', 'somehost@backend'),
@@ -338,15 +341,16 @@ class TestAdoptShareServer(TestShareServer):
             'somehost@backend',
             self.share_network['id'],
             'share_server_identifier',
-            '--share-network-subnet', self.share_network_subnet['id'],
-            '--wait'
+            '--share-network-subnet',
+            self.share_network_subnet['id'],
+            '--wait',
         ]
         verifylist = [
             ('host', 'somehost@backend'),
             ('share_network', self.share_network['id']),
             ('identifier', 'share_server_identifier'),
             ('share_network_subnet', self.share_network_subnet['id']),
-            ('wait', True)
+            ('wait', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -358,7 +362,7 @@ class TestAdoptShareServer(TestShareServer):
                 share_network_id=self.share_network['id'],
                 identifier='share_server_identifier',
                 driver_options={},
-                share_network_subnet_id=self.share_network_subnet['id']
+                share_network_subnet_id=self.share_network_subnet['id'],
             )
 
     def test_share_server_adopt_subnet_not_supported(self):
@@ -366,33 +370,33 @@ class TestAdoptShareServer(TestShareServer):
             'somehost@backend',
             self.share_network['id'],
             'share_server_identifier',
-            '--share-network-subnet', self.share_network_subnet['id'],
-            '--wait'
+            '--share-network-subnet',
+            self.share_network_subnet['id'],
+            '--wait',
         ]
         verifylist = [
             ('host', 'somehost@backend'),
             ('share_network', self.share_network['id']),
             ('identifier', 'share_server_identifier'),
             ('share_network_subnet', self.share_network_subnet['id']),
-            ('wait', True)
+            ('wait', True),
         ]
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            "2.50")
+            "2.50"
+        )
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.assertRaises(exceptions.CommandError,
-                          self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
 
 class TestAbandonShareServer(TestShareServer):
-
     def setUp(self):
-        super(TestAbandonShareServer, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server())
+        self.share_server = manila_fakes.FakeShareServer.create_one_server()
         self.servers_mock.get.return_value = self.share_server
 
         self.cmd = osc_share_servers.AbandonShareServer(self.app, None)
@@ -404,33 +408,30 @@ class TestAbandonShareServer(TestShareServer):
         arglist = []
         verifylist = []
 
-        self.assertRaises(osc_utils.ParserException,
-                          self.check_parser, self.cmd, arglist, verifylist)
+        self.assertRaises(
+            osc_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_share_server_abandon(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_server', [self.share_server.id])
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_server', [self.share_server.id])]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
-        self.servers_mock.unmanage.assert_called_with(
-            self.share_server)
+        self.servers_mock.unmanage.assert_called_with(self.share_server)
         self.assertIsNone(result)
 
     def test_share_server_abandon_multiple(self):
-        share_servers = (
-            manila_fakes.FakeShareServer.create_share_servers(
-                count=2))
-        arglist = [
-            share_servers[0].id,
-            share_servers[1].id
-        ]
+        share_servers = manila_fakes.FakeShareServer.create_share_servers(
+            count=2
+        )
+        arglist = [share_servers[0].id, share_servers[1].id]
         verifylist = [
             ('share_server', [share_servers[0].id, share_servers[1].id])
         ]
@@ -438,18 +439,16 @@ class TestAbandonShareServer(TestShareServer):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.assertEqual(self.servers_mock.unmanage.call_count,
-                         len(share_servers))
+        self.assertEqual(
+            self.servers_mock.unmanage.call_count, len(share_servers)
+        )
         self.assertIsNone(result)
 
     def test_share_server_abandon_force(self):
-        arglist = [
-            self.share_server.id,
-            '--force'
-        ]
+        arglist = [self.share_server.id, '--force']
         verifylist = [
             ('share_server', [self.share_server.id]),
-            ('force', True)
+            ('force', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -457,8 +456,8 @@ class TestAbandonShareServer(TestShareServer):
         result = self.cmd.take_action(parsed_args)
 
         self.servers_mock.unmanage.assert_called_with(
-            self.share_server,
-            force=True)
+            self.share_server, force=True
+        )
         self.assertIsNone(result)
 
     def test_share_server_abandon_force_exception(self):
@@ -472,87 +471,68 @@ class TestAbandonShareServer(TestShareServer):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.servers_mock.unmanage.side_effect = exceptions.CommandError()
-        self.assertRaises(exceptions.CommandError,
-                          self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
     def test_share_server_abandon_wait(self):
-        arglist = [
-            self.share_server.id,
-            '--wait'
-        ]
-        verifylist = [
-            ('share_server', [self.share_server.id]),
-            ('wait', True)
-        ]
+        arglist = [self.share_server.id, '--wait']
+        verifylist = [('share_server', [self.share_server.id]), ('wait', True)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         with mock.patch('osc_lib.utils.wait_for_delete', return_value=True):
             result = self.cmd.take_action(parsed_args)
-            self.servers_mock.unmanage.assert_called_with(
-                self.share_server)
+            self.servers_mock.unmanage.assert_called_with(self.share_server)
             self.assertIsNone(result)
 
     def test_share_server_abandon_wait_error(self):
-        arglist = [
-            self.share_server.id,
-            '--wait'
-        ]
-        verifylist = [
-            ('share_server', [self.share_server.id]),
-            ('wait', True)
-        ]
+        arglist = [self.share_server.id, '--wait']
+        verifylist = [('share_server', [self.share_server.id]), ('wait', True)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         with mock.patch('osc_lib.utils.wait_for_delete', return_value=False):
             self.assertRaises(
-                exceptions.CommandError,
-                self.cmd.take_action,
-                parsed_args)
+                exceptions.CommandError, self.cmd.take_action, parsed_args
+            )
 
 
 class TestSetShareServer(TestShareServer):
-
     def setUp(self):
-        super(TestSetShareServer, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                methods={'reset_task_state': None}
-            )
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            methods={'reset_task_state': None}
         )
         self.servers_mock.get.return_value = self.share_server
 
         self.cmd = osc_share_servers.SetShareServer(self.app, None)
 
     def test_share_server_set_status(self):
-        arglist = [
-            self.share_server.id,
-            '--status', 'active'
-        ]
+        arglist = [self.share_server.id, '--status', 'active']
         verifylist = [
             ('share_server', self.share_server.id),
-            ('status', 'active')
+            ('status', 'active'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.servers_mock.reset_state.assert_called_with(
-            self.share_server,
-            parsed_args.status)
+            self.share_server, parsed_args.status
+        )
         self.assertIsNone(result)
 
     def test_share_server_set_task_state(self):
         arglist = [
             self.share_server.id,
-            '--task-state', 'migration_in_progress'
+            '--task-state',
+            'migration_in_progress',
         ]
         verifylist = [
             ('share_server', self.share_server.id),
-            ('task_state', 'migration_in_progress')
+            ('task_state', 'migration_in_progress'),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -560,41 +540,69 @@ class TestSetShareServer(TestShareServer):
         result = self.cmd.take_action(parsed_args)
 
         self.servers_mock.reset_task_state.assert_called_with(
-            self.share_server,
-            parsed_args.task_state)
+            self.share_server, parsed_args.task_state
+        )
         self.assertIsNone(result)
 
-    def test_share_server_set_status_exception(self):
+    def test_share_server_set_task_state_none(self):
         arglist = [
             self.share_server.id,
-            '--status', 'active'
+            '--task-state',
         ]
         verifylist = [
             ('share_server', self.share_server.id),
-            ('status', 'active')
+            ('task_state', None),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.servers_mock.reset_task_state.assert_called_with(
+            self.share_server, None
+        )
+        self.assertIsNone(result)
+
+    def test_share_server_set_task_state_string_none(self):
+        arglist = [self.share_server.id, '--task-state', 'None']
+        verifylist = [
+            ('share_server', self.share_server.id),
+            ('task_state', 'None'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.servers_mock.reset_task_state.assert_called_with(
+            self.share_server, None
+        )
+        self.assertIsNone(result)
+
+    def test_share_server_set_status_exception(self):
+        arglist = [self.share_server.id, '--status', 'active']
+        verifylist = [
+            ('share_server', self.share_server.id),
+            ('status', 'active'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.servers_mock.reset_state.side_effect = Exception()
 
         self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
 
 class TestShareServerMigrationCancel(TestShareServer):
-
     def setUp(self):
-        super(TestShareServerMigrationCancel, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                attrs={
-                    'status': 'migrating',
-                },
-                methods={'migration_cancel': None}
-            )
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            attrs={
+                'status': 'migrating',
+            },
+            methods={'migration_cancel': None},
         )
         self.servers_mock.get.return_value = self.share_server
 
@@ -602,78 +610,71 @@ class TestShareServerMigrationCancel(TestShareServer):
         self.cmd = osc_share_servers.ShareServerMigrationCancel(self.app, None)
 
     def test_share_server_migration_cancel(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_server', self.share_server.id)
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_server', self.share_server.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
         self.share_server.migration_cancel.assert_called
 
 
 class TestShareServerMigrationComplete(TestShareServer):
-
     def setUp(self):
-        super(TestShareServerMigrationComplete, self).setUp()
+        super().setUp()
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                attrs={
-                    'status': 'migrating',
-                },
-                methods={'migration_complete': None}
-            )
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            attrs={
+                'status': 'migrating',
+            },
+            methods={'migration_complete': None},
         )
         self.servers_mock.get.return_value = self.share_server
 
         # Get the command objects to test
         self.cmd = osc_share_servers.ShareServerMigrationComplete(
-            self.app, None)
+            self.app, None
+        )
 
     def test_share_server_migration_complete(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_server', self.share_server.id)
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_server', self.share_server.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
         self.share_server.migration_complete.assert_called
 
 
 class TestShareServerMigrationShow(TestShareServer):
-
     def setUp(self):
-        super(TestShareServerMigrationShow, self).setUp()
+        super().setUp()
 
-        self.new_share_network = manila_fakes.FakeShareNetwork \
-            .create_one_share_network()
+        self.new_share_network = (
+            manila_fakes.FakeShareNetwork.create_one_share_network()
+        )
         self.share_networks_mock.get.return_value = self.new_share_network
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                attrs={
-                    'status': 'migrating',
-                    'task_state': 'migration_in_progress'
-                },
-                methods={'migration_get_progress': None}
-            )
+        migration_dict = {
+            'total_progress': 'fake',
+            'task_state': 'migration_in_progress',
+            'destination_share_server_id': 'fake_id',
+        }
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            attrs={
+                'status': 'migrating',
+                'task_state': 'migration_in_progress',
+            },
+            methods={'migration_get_progress': None},
         )
         self.servers_mock.get.return_value = self.share_server
+        share_client = self.app.client_manager.share
+        share_client.share_servers.migration_get_progress.return_value = (
+            migration_dict
+        )
 
         # Get the command objects to test
         self.cmd = osc_share_servers.ShareServerMigrationShow(self.app, None)
 
     def test_share_server_migration_show(self):
-        arglist = [
-            self.share_server.id
-        ]
-        verifylist = [
-            ('share_server', self.share_server.id)
-        ]
+        arglist = [self.share_server.id]
+        verifylist = [('share_server', self.share_server.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
         self.share_server.migration_get_progress.assert_called
@@ -681,19 +682,19 @@ class TestShareServerMigrationShow(TestShareServer):
 
 class TestShareServerMigrationStart(TestShareServer):
     def setUp(self):
-        super(TestShareServerMigrationStart, self).setUp()
+        super().setUp()
 
-        self.new_share_network = manila_fakes.FakeShareNetwork \
-            .create_one_share_network()
+        self.new_share_network = (
+            manila_fakes.FakeShareNetwork.create_one_share_network()
+        )
         self.share_networks_mock.get.return_value = self.new_share_network
 
-        self.share_server = (
-            manila_fakes.FakeShareServer.create_one_server(
-                attrs={
-                    'check_only': 'False',
-                },
-                methods={'migration_start': None, 'migration_check': None}
-            ))
+        self.share_server = manila_fakes.FakeShareServer.create_one_server(
+            attrs={
+                'check_only': 'False',
+            },
+            methods={'migration_start': None, 'migration_check': None},
+        )
         self.servers_mock.get.return_value = self.share_server
 
         # Get the command objects to test
@@ -705,10 +706,14 @@ class TestShareServerMigrationStart(TestShareServer):
         arglist = [
             '1234',
             'host@backend',
-            '--preserve-snapshots', 'False',
-            '--writable', 'False',
-            '--nondisruptive', 'False',
-            '--new-share-network', self.new_share_network.id
+            '--preserve-snapshots',
+            'False',
+            '--writable',
+            'False',
+            '--nondisruptive',
+            'False',
+            '--new-share-network',
+            self.new_share_network.id,
         ]
 
         verifylist = [
@@ -717,11 +722,12 @@ class TestShareServerMigrationStart(TestShareServer):
             ('preserve_snapshots', 'False'),
             ('writable', 'False'),
             ('nondisruptive', 'False'),
-            ('new_share_network', self.new_share_network.id)
+            ('new_share_network', self.new_share_network.id),
         ]
 
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            "2.57")
+            "2.57"
+        )
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
@@ -730,7 +736,7 @@ class TestShareServerMigrationStart(TestShareServer):
             'False',
             'False',
             'False',
-            self.new_share_network.id
+            self.new_share_network.id,
         )
         self.assertEqual(result, ({}, {}))
 
@@ -740,10 +746,14 @@ class TestShareServerMigrationStart(TestShareServer):
         arglist = [
             '1234',
             'host@backend',
-            '--preserve-snapshots', 'True',
-            '--writable', 'True',
-            '--nondisruptive', 'False',
-            '--new-share-network', self.new_share_network.id,
+            '--preserve-snapshots',
+            'True',
+            '--writable',
+            'True',
+            '--nondisruptive',
+            'False',
+            '--new-share-network',
+            self.new_share_network.id,
             '--check-only',
         ]
 
@@ -754,7 +764,7 @@ class TestShareServerMigrationStart(TestShareServer):
             ('writable', 'True'),
             ('nondisruptive', 'False'),
             ('new_share_network', self.new_share_network.id),
-            ('check_only', True)
+            ('check_only', True),
         ]
 
         expected_result = {
@@ -764,7 +774,7 @@ class TestShareServerMigrationStart(TestShareServer):
                 'nondisruptive': 'False',
                 'preserve_snapshots': 'True',
                 'share_network_id': None,
-                'host': 'host@backend'
+                'host': 'host@backend',
             },
             'supported_capabilities': {
                 'writable': True,
@@ -772,14 +782,15 @@ class TestShareServerMigrationStart(TestShareServer):
                 'preserve_snapshots': True,
                 'share_network_id': self.new_share_network.id,
                 'migration_cancel': True,
-                'migration_get_progress': True
-            }
+                'migration_get_progress': True,
+            },
         }
 
         self.share_server.migration_check.return_value = expected_result
 
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            "2.57")
+            "2.57"
+        )
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
@@ -789,7 +800,6 @@ class TestShareServerMigrationStart(TestShareServer):
             'False',
             'True',
             self.new_share_network.id,
-
         )
         result_dict = {}
         for count, column in enumerate(columns):
@@ -800,14 +810,19 @@ class TestShareServerMigrationStart(TestShareServer):
         """Test share server migration start with API microversion exception"""
 
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            "2.50")
+            "2.50"
+        )
         arglist = [
             '1234',
             'host@backend',
-            '--preserve-snapshots', 'False',
-            '--writable', 'False',
-            '--nondisruptive', 'False',
-            '--new-share-network', self.new_share_network.id
+            '--preserve-snapshots',
+            'False',
+            '--writable',
+            'False',
+            '--nondisruptive',
+            'False',
+            '--new-share-network',
+            self.new_share_network.id,
         ]
 
         verifylist = [
@@ -816,12 +831,11 @@ class TestShareServerMigrationStart(TestShareServer):
             ('preserve_snapshots', 'False'),
             ('writable', 'False'),
             ('nondisruptive', 'False'),
-            ('new_share_network', self.new_share_network.id)
+            ('new_share_network', self.new_share_network.id),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
