@@ -13,20 +13,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from manilaclient.tests.unit import utils
 
 
 class LimitsV1Test(utils.TestCase):
-
     def test_import_v1_limits_module(self):
         try:
             from manilaclient.v1 import limits
         except Exception as e:
-            msg = ("module 'manilaclient.v1.limits' cannot be imported "
-                   "with error: %s") % six.text_type(e)
+            msg = (
+                "module 'manilaclient.v1.limits' cannot be imported "
+                f"with error: {str(e)}"
+            )
             assert False, msg
         for cls in ('Limits', 'RateLimit', 'AbsoluteLimit', 'LimitsManager'):
-            msg = "Module 'limits' has no '%s' attr." % cls
+            msg = f"Module 'limits' has no '{cls}' attr."
             self.assertTrue(hasattr(limits, cls), msg)
