@@ -13,20 +13,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from manilaclient.tests.unit import utils
 
 
 class ShareTypesV1Test(utils.TestCase):
-
     def test_import_v1_share_types_module(self):
         try:
             from manilaclient.v1 import share_types
         except Exception as e:
-            msg = ("module 'manilaclient.v1.share_types' cannot be imported "
-                   "with error: %s") % six.text_type(e)
+            msg = (
+                "module 'manilaclient.v1.share_types' cannot be imported "
+                f"with error: {str(e)}"
+            )
             assert False, msg
         for cls in ('ShareType', 'ShareTypeManager'):
-            msg = "Module 'share_types' has no '%s' attr." % cls
+            msg = f"Module 'share_types' has no '{cls}' attr."
             self.assertTrue(hasattr(share_types, cls), msg)
