@@ -10,9 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from debtcollector import removals
 from keystoneauth1 import adapter
+from keystoneauth1 import identity
 from keystoneauth1 import session
-from keystoneclient import client as ks_client
 
 import manilaclient
 from manilaclient.common import constants
@@ -21,12 +22,15 @@ from manilaclient import exceptions
 from manilaclient.v2 import availability_zones
 from manilaclient.v2 import limits
 from manilaclient.v2 import messages
+from manilaclient.v2 import qos_types
 from manilaclient.v2 import quota_classes
 from manilaclient.v2 import quotas
+from manilaclient.v2 import resource_locks
 from manilaclient.v2 import scheduler_stats
 from manilaclient.v2 import security_services
 from manilaclient.v2 import services
 from manilaclient.v2 import share_access_rules
+from manilaclient.v2 import share_backups
 from manilaclient.v2 import share_export_locations
 from manilaclient.v2 import share_group_snapshots
 from manilaclient.v2 import share_group_type_access
@@ -43,12 +47,13 @@ from manilaclient.v2 import share_snapshot_export_locations
 from manilaclient.v2 import share_snapshot_instance_export_locations
 from manilaclient.v2 import share_snapshot_instances
 from manilaclient.v2 import share_snapshots
+from manilaclient.v2 import share_transfers
 from manilaclient.v2 import share_type_access
 from manilaclient.v2 import share_types
 from manilaclient.v2 import shares
 
 
-class Client(object):
+class Client:
     """Top-level object to access the OpenStack Manila API.
 
     Create an instance with your creds::
@@ -61,13 +66,15 @@ class Client(object):
     Or, alternatively, you can create a client instance using the
     keystoneauth1.session API::
 
-        >>> from keystoneclient.auth.identity import v2
+        >>> from keystoneauth1.identity import v3
         >>> from keystoneauth1 import session
         >>> from manilaclient import client
-        >>> auth = v2.Password(auth_url=AUTH_URL,
+        >>> auth = v3.Password(auth_url=AUTH_URL,
                                username=USERNAME,
+                               user_domain_name=USER_DOMAIN_NAME,
                                password=PASSWORD,
-                               tenant_name=PROJECT_ID)
+                               project_name=PROJECT_ID,
+                               project_domain_name=PROJECT_DOMAIN_NAME)
         >>> sess = session.Session(auth=auth)
         >>> manila = client.Client(VERSION, session=sess)
 
@@ -76,26 +83,60 @@ class Client(object):
         >>> client.shares.list()
         ...
     """
-    def __init__(self, username=None, project_id=None, auth_url=None,
-                 insecure=False, timeout=None, tenant_id=None,
-                 project_name=None, region_name=None,
-                 endpoint_type='publicURL', extensions=None,
-                 service_type=constants.V2_SERVICE_TYPE, service_name=None,
-                 retries=None, http_log_debug=False, input_auth_token=None,
-                 session=None, auth=None, cacert=None,
-                 service_catalog_url=None, user_agent='python-manilaclient',
-                 use_keyring=False, force_new_token=False,
-                 cached_token_lifetime=300,
-                 api_version=manilaclient.API_MIN_VERSION,
-                 user_id=None,
-                 user_domain_id=None,
-                 user_domain_name=None,
-                 project_domain_id=None,
-                 project_domain_name=None,
-                 cert=None,
-                 password=None,
-                 **kwargs):
 
+    @removals.removed_kwarg(
+        'use_keyring',
+        message='This parameter is no longer supported and has no effect.',
+        version='5.8.0',
+        removal_version='6.0.0',
+    )
+    @removals.removed_kwarg(
+        'force_new_token',
+        message='This parameter is no longer supported and has no effect.',
+        version='5.8.0',
+        removal_version='6.0.0',
+    )
+    @removals.removed_kwarg(
+        'cached_token_lifetime',
+        message='This parameter is no longer supported and has no effect.',
+        version='5.8.0',
+        removal_version='6.0.0',
+    )
+    def __init__(
+        self,
+        username=None,
+        project_id=None,
+        auth_url=None,
+        insecure=False,
+        timeout=None,
+        tenant_id=None,
+        project_name=None,
+        region_name=None,
+        endpoint_type='publicURL',
+        extensions=None,
+        service_type=constants.V2_SERVICE_TYPE,
+        service_name=None,
+        retries=None,
+        http_log_debug=False,
+        input_auth_token=None,
+        session=None,
+        auth=None,
+        cacert=None,
+        service_catalog_url=None,
+        user_agent='python-manilaclient',
+        use_keyring=False,
+        force_new_token=False,
+        cached_token_lifetime=300,
+        api_version=manilaclient.API_MIN_VERSION,
+        user_id=None,
+        user_domain_id=None,
+        user_domain_name=None,
+        project_domain_id=None,
+        project_domain_name=None,
+        cert=None,
+        password=None,
+        **kwargs,
+    ):
         self.username = username
         self.password = password
         self.tenant_id = tenant_id or project_id
@@ -117,13 +158,11 @@ class Client(object):
         self.cert = cert
         self.insecure = insecure
 
-        self.use_keyring = use_keyring
-        self.force_new_token = force_new_token
-        self.cached_token_lifetime = cached_token_lifetime
-
         if input_auth_token and not service_catalog_url:
-            msg = ("For token-based authentication you should "
-                   "provide 'input_auth_token' and 'service_catalog_url'.")
+            msg = (
+                "For token-based authentication you should "
+                "provide 'input_auth_token' and 'service_catalog_url'."
+            )
             raise exceptions.ClientException(msg)
 
         self.project_id = tenant_id if tenant_id is not None else project_id
@@ -135,92 +174,107 @@ class Client(object):
         # if token is provided.
         if not input_auth_token:
             if session:
+                # Modern path - session provided by caller (e.g., OSC plugin)
                 self.keystone_client = adapter.LegacyJsonAdapter(
                     session=session,
                     auth=auth,
                     interface=endpoint_type,
                     service_type=service_type,
                     service_name=service_name,
-                    region_name=region_name)
+                    region_name=region_name,
+                )
                 input_auth_token = self.keystone_client.session.get_token(auth)
-
             else:
-                self.keystone_client = self._get_keystone_client()
-                input_auth_token = self.keystone_client.auth_token
+                # Legacy path - create auth plugin and session ourselves
+                auth, ks_session = self._get_keystone_auth_and_session()
+                self.keystone_client = adapter.LegacyJsonAdapter(
+                    session=ks_session,
+                    auth=auth,
+                    interface=endpoint_type,
+                    service_type=service_type,
+                    service_name=service_name,
+                    region_name=region_name,
+                )
+                input_auth_token = self.keystone_client.session.get_token(auth)
 
         if not input_auth_token:
             raise RuntimeError("Not Authorized")
 
-        if session and not service_catalog_url:
+        if not service_catalog_url:
+            # Use keystoneauth1 session endpoint discovery
             service_catalog_url = self.keystone_client.session.get_endpoint(
-                auth, interface=endpoint_type,
-                service_type=service_type)
-        elif not service_catalog_url:
-            catalog = self.keystone_client.service_catalog.get_endpoints(
-                service_type)
-            for catalog_entry in catalog.get(service_type, []):
-                if (catalog_entry.get("interface") == (
-                        endpoint_type.lower().split("url")[0]) or
-                        catalog_entry.get(endpoint_type)):
-                    if (region_name and not region_name == (
-                            catalog_entry.get(
-                                "region",
-                                catalog_entry.get("region_id")))):
-                        continue
-                    service_catalog_url = catalog_entry.get(
-                        "url", catalog_entry.get(endpoint_type))
-                    break
+                self.keystone_client.auth,
+                interface=endpoint_type,
+                service_type=service_type,
+                region_name=region_name,
+            )
 
         if not service_catalog_url:
             raise RuntimeError("Could not find Manila endpoint in catalog")
 
         self.api_version = api_version
-        self.client = httpclient.HTTPClient(service_catalog_url,
-                                            input_auth_token,
-                                            user_agent,
-                                            insecure=insecure,
-                                            cacert=cacert,
-                                            cert=cert,
-                                            timeout=timeout,
-                                            retries=retries,
-                                            http_log_debug=http_log_debug,
-                                            api_version=self.api_version)
+        self.client = httpclient.HTTPClient(
+            service_catalog_url,
+            input_auth_token,
+            user_agent,
+            insecure=insecure,
+            cacert=cacert,
+            cert=cert,
+            timeout=timeout,
+            retries=retries,
+            http_log_debug=http_log_debug,
+            api_version=self.api_version,
+        )
 
         self.availability_zones = availability_zones.AvailabilityZoneManager(
-            self)
+            self
+        )
         self.limits = limits.LimitsManager(self)
+        self.transfers = share_transfers.ShareTransferManager(self)
         self.messages = messages.MessageManager(self)
+        self.qos_types = qos_types.QosTypeManager(self)
         self.services = services.ServiceManager(self)
         self.security_services = security_services.SecurityServiceManager(self)
         self.share_networks = share_networks.ShareNetworkManager(self)
         self.share_network_subnets = (
-            share_network_subnets.ShareNetworkSubnetManager(self))
+            share_network_subnets.ShareNetworkSubnetManager(self)
+        )
 
         self.quota_classes = quota_classes.QuotaClassSetManager(self)
         self.quotas = quotas.QuotaSetManager(self)
 
+        self.resource_locks = resource_locks.ResourceLockManager(self)
+
         self.shares = shares.ShareManager(self)
         self.share_export_locations = (
-            share_export_locations.ShareExportLocationManager(self))
+            share_export_locations.ShareExportLocationManager(self)
+        )
         self.share_groups = share_groups.ShareGroupManager(self)
         self.share_group_snapshots = (
-            share_group_snapshots.ShareGroupSnapshotManager(self))
+            share_group_snapshots.ShareGroupSnapshotManager(self)
+        )
         self.share_group_type_access = (
-            share_group_type_access.ShareGroupTypeAccessManager(self))
+            share_group_type_access.ShareGroupTypeAccessManager(self)
+        )
         self.share_group_types = share_group_types.ShareGroupTypeManager(self)
         self.share_instances = share_instances.ShareInstanceManager(self)
         self.share_instance_export_locations = (
             share_instance_export_locations.ShareInstanceExportLocationManager(
-                self))
+                self
+            )
+        )
         self.share_snapshots = share_snapshots.ShareSnapshotManager(self)
         self.share_snapshot_instances = (
-            share_snapshot_instances.ShareSnapshotInstanceManager(self))
+            share_snapshot_instances.ShareSnapshotInstanceManager(self)
+        )
         self.share_snapshot_export_locations = (
             share_snapshot_export_locations.ShareSnapshotExportLocationManager(
-                self))
-        self.share_snapshot_instance_export_locations = (
-            share_snapshot_instance_export_locations.
-            ShareSnapshotInstanceExportLocationManager(self))
+                self
+            )
+        )
+        self.share_snapshot_instance_export_locations = share_snapshot_instance_export_locations.ShareSnapshotInstanceExportLocationManager(  # noqa: E501
+            self
+        )
 
         self.share_types = share_types.ShareTypeManager(self)
         self.share_type_access = share_type_access.ShareTypeAccessManager(self)
@@ -228,10 +282,14 @@ class Client(object):
         self.share_replicas = share_replicas.ShareReplicaManager(self)
         self.share_replica_export_locations = (
             share_replica_export_locations.ShareReplicaExportLocationManager(
-                self))
+                self
+            )
+        )
         self.pools = scheduler_stats.PoolManager(self)
-        self.share_access_rules = (
-            share_access_rules.ShareAccessRuleManager(self))
+        self.share_access_rules = share_access_rules.ShareAccessRuleManager(
+            self
+        )
+        self.share_backups = share_backups.ShareBackupManager(self)
 
         self._load_extensions(extensions)
 
@@ -243,54 +301,40 @@ class Client(object):
             if extension.manager_class:
                 setattr(self, extension.name, extension.manager_class(self))
 
-    def _get_keystone_client(self):
-        # First create a Keystone session
+    def _get_keystone_auth_and_session(self):
+        """Create keystoneauth1 auth plugin and session for authentication.
+
+        Returns:
+            tuple: (auth_plugin, session) for use with keystoneauth1
+        """
+        # Create session with SSL settings
         if self.insecure:
             verify = False
         else:
             verify = self.cacert or True
         ks_session = session.Session(verify=verify, cert=self.cert)
 
-        # Discover the supported keystone versions using the given url
+        # Discover Keystone v3 endpoint
         ks_discover = session.discover.Discover(ks_session, self.auth_url)
-
-        # Inspect the auth_url to see the supported version. If both v3 and v2
-        # are supported, then use the highest version if possible.
-        v2_auth_url = ks_discover.url_for('v2.0')
-        v3_auth_url = ks_discover.url_for('v3.0')
-
-        if v3_auth_url:
-            keystone_client = ks_client.Client(
-                session=ks_session,
-                version=(3, 0),
-                auth_url=v3_auth_url,
-                username=self.username,
-                password=self.password,
-                user_id=self.user_id,
-                user_domain_name=self.user_domain_name,
-                user_domain_id=self.user_domain_id,
-                project_id=self.project_id or self.tenant_id,
-                project_name=self.project_name,
-                project_domain_name=self.project_domain_name,
-                project_domain_id=self.project_domain_id,
-                region_name=self.region_name)
-        elif v2_auth_url:
-            keystone_client = ks_client.Client(
-                session=ks_session,
-                version=(2, 0),
-                auth_url=v2_auth_url,
-                username=self.username,
-                password=self.password,
-                tenant_id=self.tenant_id,
-                tenant_name=self.tenant_name,
-                region_name=self.region_name,
-                cert=self.cert,
-                use_keyring=self.use_keyring,
-                force_new_token=self.force_new_token,
-                stale_duration=self.cached_token_lifetime)
-        else:
+        auth_url = ks_discover.url_for('v3.0')
+        if not auth_url:
             raise exceptions.CommandError(
                 'Unable to determine the Keystone version to authenticate '
-                'with using the given auth_url.')
-        keystone_client.authenticate()
-        return keystone_client
+                'with using the given auth_url.'
+            )
+
+        # Create v3 Password auth plugin
+        auth = identity.v3.Password(
+            auth_url=auth_url,
+            username=self.username,
+            password=self.password,
+            user_id=self.user_id,
+            user_domain_name=self.user_domain_name,
+            user_domain_id=self.user_domain_id,
+            project_id=self.project_id or self.tenant_id,
+            project_name=self.project_name,
+            project_domain_name=self.project_domain_name,
+            project_domain_id=self.project_domain_id,
+        )
+
+        return auth, ks_session
